@@ -1,7 +1,5 @@
 context("dplyr and broom")
 
-suppressPackageStartupMessages(library(dplyr))
-
 # set up the lahman batting table, and filter to make it faster
 batting <- tbl(lahman_df(), "Batting")
 batting <- batting %>% filter(yearID > 1980)
@@ -11,7 +9,7 @@ lm0 <- failwith(NULL, lm, quiet = TRUE)
 test_that("can perform regressions with tidying in dplyr", {
     regressions <- batting %>% group_by(yearID) %>% do(tidy(lm0(SB ~ CS, data=.)))
         
-    expect_less_than(30, nrow(regressions))
+    expect_lt(30, nrow(regressions))
     expect_true(all(c("yearID", "estimate", "statistic", "p.value") %in%
                     colnames(regressions)))
 })
@@ -34,12 +32,12 @@ test_that("can perform correlations with tidying in dplyr", {
     pcors <- batting %>% group_by(yearID) %>% do(tidy(cor.test0(.$SB, .$CS)))
     expect_true(all(c("yearID", "estimate", "statistic", "p.value") %in%
                         colnames(pcors)))
-    expect_less_than(30, nrow(pcors))
+    expect_lt(30, nrow(pcors))
 
     scors <- suppressWarnings(batting %>% group_by(yearID) %>%
                                  do(tidy(cor.test0(.$SB, .$CS, method="spearman"))))
     expect_true(all(c("yearID", "estimate", "statistic", "p.value") %in%
                         colnames(scors)))
-    expect_less_than(30, nrow(scors))
+    expect_lt(30, nrow(scors))
     expect_false(all(pcors$estimate == scors$estimate))
 })
